from setuptools import setup
setup(
    name="askky",
    version="1.1",
    description="Askky Python Client",
    url="https://github.com/Askky/python-askky-sdk.git",
    author="Team Askky",
    author_email="hello@razorpay.com",
    license="MIT",
    install_requires=["requests"],
    include_package_data=True,
    package_dir={'askky': 'askky'},
    packages=['askky'],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",

        # List of supported Python versions
        "Programming Language :: Python",
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',

        "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)


import json
import requests

class Client:
    def __init__(self,privateKey=None):
        self.base_url = "https://api.askky.co/"
        self.privateKey = privateKey

    def trigger_survey(self, survey_id, user_id, **kwargs):
        """"
        trigger specific survey for a user
        Args:
            survey_id : Id of the Survey that you want to call
            user_id : Id of the user to whom you want to show the Survey
        Returns:
            Success Response Dict
        """
        
        
        url = str(self.base_url) + str('trigger/form/')
        data = {}
        data["privateKey"] = self.privateKey
        data["campaignId"] = survey_id
        data["userId"] = user_id
        print ('data',json.dumps(data))
        headers = {'Content-Type': 'application/json'}
        response = requests.post(url,data=str(json.dumps(data)),headers=headers)

        return response
